@@ -13,7 +13,6 @@ import re
 import sys
 import datetime
 import time
-from time import sleep
 from threading import Thread as thr
 from functools import wraps
 from rich.panel import Panel
@@ -37,7 +36,7 @@ getExc = lambda e: e.args[1] if len(e.args) > 1 else str(e)
 
 rich_code_themes = ["monokai", "paraiso-dark", "igor", "vs", "fruity", "xcode"]
 
-default_provider = "leo"
+default_provider = "Aura"
 
 logging.basicConfig(
     format="%(asctime)s - %(levelname)s : %(message)s ",  # [%(module)s,%(lineno)s]", # for debug purposes
@@ -157,7 +156,7 @@ class busy_bar:
                 print(" " + spin, end="\r", flush=True)
                 if not cls.querying:
                     break
-                sleep(cls.sleep_time)
+                time.sleep(cls.sleep_time)
 
     @classmethod
     def start_spinning(
@@ -180,7 +179,7 @@ class busy_bar:
         """Stop displaying busy-bar"""
         if cls.querying:
             cls.querying = False
-            sleep(cls.sleep_time)
+            time.sleep(cls.sleep_time)
 
     @classmethod
     def run(cls, help: str = "Exception"):
@@ -211,7 +210,11 @@ class busy_bar:
 
 
 class Main(cmd.Cmd):
-    intro = f"Welcome to AI Chat in terminal. Type 'help' or 'h' for usage info \n Submit any bug at {pytgpt.__repo__}/issues/new"
+    intro = (
+        "Welcome to AI Chat in terminal. "
+        "Type 'help' or 'h' for usage info.\n"
+        f"Submit any bug at {pytgpt.__repo__}/issues/new"
+    )
 
     def __init__(
         self,
@@ -231,6 +234,7 @@ class Main(cmd.Cmd):
         proxy_path,
         provider,
         quiet=False,
+        chat_completion=False,
         *args,
         **kwargs,
     ):
@@ -311,6 +315,7 @@ class Main(cmd.Cmd):
 
                 self.bot = OPENGPT(
                     is_conversation=disable_conversation,
+                    max_tokens=max_tokens,
                     timeout=timeout,
                     intro=intro,
                     filepath=filepath,
@@ -349,6 +354,23 @@ class Main(cmd.Cmd):
                     timeout=timeout,
                 )
 
+            elif provider in pytgpt.gpt4free_providers:
+                from pytgpt.gpt4free import GPT4FREE
+                self.bot = GPT4FREE(
+                    provider=provider,
+                    is_conversation=disable_conversation,
+                    max_tokens=max_tokens,
+                    model=model,
+                    chat_completion=chat_completion,
+                    timeout=timeout,
+                    intro=intro,
+                    filepath=filepath,
+                    update_file=update_file,
+                    proxies=proxies,
+                    history_offset=history_offset,
+                    act=awesome_prompt,
+                )
+
             else:
                 raise NotImplementedError(
                     f"The provider `{provider}` is not yet implemented."
@@ -472,7 +494,7 @@ class Main(cmd.Cmd):
 
     @busy_bar.run("Settings saved")
     def do_settings(self, line):
-        """Configre settings"""
+        """Configure settings"""
         self.prettify = click.confirm(
             "\nPrettify markdown response", default=self.prettify
         )
@@ -481,7 +503,9 @@ class Main(cmd.Cmd):
             default=busy_bar.spin_index,
             type=click.IntRange(0, 3),
         )
-        self.color = click.prompt("Response stdout font color", default=self.color)
+        self.color = click.prompt(
+            "Response stdout font color", default=self.color or "white"
+        )
         self.code_theme = Prompt.ask(
             "Enter code_theme", choices=rich_code_themes, default=self.code_theme
         )
@@ -904,6 +928,12 @@ def tgpt2_():
 @click.option(
     "-nc", "--no-coloring", is_flag=True, help="Disable intro prompt font-coloring"
 )
+@click.option(
+    "-cc",
+    "--chat-completion",
+    is_flag=True,
+    help="Provide native context for gpt4free providers",
+)
 @click.help_option("-h", "--help")
 def interactive(
     model,
@@ -932,6 +962,7 @@ def interactive(
     new,
     with_copied,
     no_coloring,
+    chat_completion,
 ):
     """Chat with AI interactively (Default)"""
     clear_history_file(filepath, new)
@@ -952,6 +983,7 @@ def interactive(
         proxy_path,
         provider,
         quiet,
+        chat_completion,
     )
     busy_bar.spin_index = busy_bar_index
     bot.code_theme = code_theme
